import * as msi from 'electron-wix-msi';
import * as path from 'path';
import * as fs from 'fs';

// Step 0: Fetch data from package json
const jsonraw = fs.readFileSync(path.resolve('package.json'), 'utf-8')
const packagejson = JSON.parse(jsonraw)

// Step 1: Instantiate the MSICreator
const msiCreator = new msi.MSICreator({
  appDirectory: path.resolve('dist/Downrich-win32-x64'),
  description: packagejson.description,
  exe: packagejson.productName,
  name: packagejson.productName,
  manufacturer: packagejson.author,
  version: packagejson.version,
  arch: 'x64',
  cultures: 'de-DE;en-US;neutral',
  outputDirectory: path.resolve('dist/installers'),
  icon: path.resolve('assets/icon_app.ico'),
  ui: {
    enabled: true,
    chooseDirectory: true,
    images: {
      background: path.resolve('assets/install_bg.jpg'),
      banner: path.resolve('assets/install_banner.jpg')
    }
  }
})

// Step 2: Create a .wxs template file
const supportBinaries = await msiCreator.create();

// Adjust the template
const wxspath = path.resolve('dist/installers/Downrich.wxs');

fs.readFile(wxspath, 'utf8', function(err, data) {
  if (err) {
    return console.log(err);
  }

  let result = data.replace(/ \(Machine - MSI\)/g, '');
  result = result.replace(/<UI Id="UserInterface">([\s\S]*?)<\/UI>/g, '<Property Id="WIXUI_INSTALLDIR" Value="APPLICATIONROOTDIRECTORY"/>\n    <UIRef Id="WixUI_InstallDir"/>\n    <WixVariable Id="WixUILicenseRtf" Value="../../license.rtf" />');

  fs.writeFile(wxspath, result, 'utf8', function(err) {
    if (err) return console.log(err);
  });
});

console.log('Compiling...');

// Step 3: Compile the template to a .msi file
await msiCreator.compile();
