const { shell, contextBridge, ipcRenderer} = require('electron')
const path = require("path")

// NEOAPI for access via website
// ---------------------------------------------------------------------------

contextBridge.exposeInMainWorld('neoapi', {
    openInExplorer: (link) => {
        link = path.normalize(link)
        shell.showItemInFolder(link)
    },
    setUnreadBadge: (count) => {
        if(count < 1) {
            if(process.platform === 'darwin') {
                ipcRenderer.send('update-macos-badge', 0)
            } else if(process.platform === 'win32') {
                ipcRenderer.sendSync('update-badge', null)
            }
        } else {
            if(process.platform === 'darwin') {
                ipcRenderer.send('update-macos-badge', count)
            } else if(process.platform === 'win32') {
                ipcRenderer.sendSync('update-badge', count)
            }
        }
    },
    setProgress: (count) => ipcRenderer.send('setProgress', count),
    send: (channel, data) => {
        // whitelist channels
        let validChannels = ["newWindow", "newPopup"]
        if (validChannels.includes(channel)) {
            ipcRenderer.send(channel, data)
        }
    },
    receive: (channel, func) => {
        let validChannels = ["fromMain"]
        if (validChannels.includes(channel)) {
            // Deliberately strip event as it includes `sender`
            ipcRenderer.on(channel, (event, ...args) => func(...args))
        }
    }
})
